@@ -119,6 +119,7 @@ class ShedFixers(VisitorBasedCodemodCommand):
             comparator=oneof_names("None", "False", "True"), operator=m.Equal()
         )
     )
+    @m.call_if_not_inside(m.Index())  # Pandas idiom, e.g. df[df.flag == True]
     def convert_none_cmp(self, _, updated_node):
         """Inspired by Pybetter."""
         return updated_node.with_changes(operator=cst.Is())
@@ -281,12 +282,25 @@ class ShedFixers(VisitorBasedCodemodCommand):
     def reorder_union_literal_contents_none_last(self, _, updated_node):
         subscript = list(updated_node.slice)
         try:
+            has_comma = isinstance(subscript[-1].comma, cst.Comma)
             subscript.sort(key=lambda elt: elt.slice.value.value == "None")
-            subscript[-1] = remove_trailing_comma(subscript[-1])
+            if not has_comma:
+                subscript[-1] = remove_trailing_comma(subscript[-1])
             return updated_node.with_changes(slice=subscript)
         except Exception:  # Single-element literals are not slices, etc.
             return updated_node
 
+    @m.leave(
+        m.Subscript(
+            m.Name("Optional"),
+            [m.SubscriptElement(m.Index(m.Subscript(value=m.Name("Union"))))],
+        )
+    )
+    def reorder_merge_optional_union(self, _, updated_node):
+        union = updated_node.slice[0].slice.value
+        none = [cst.SubscriptElement(cst.Index(cst.Name("None")))]
+        return union.with_changes(slice=list(union.slice) + none)
+
     @m.call_if_inside(m.Annotation(annotation=m.BinaryOperation()))
     @m.leave(
         m.BinaryOperation(
